@@ -1,6 +1,6 @@
 """module for producing astronomical plots
 
-(c) 2007-2013 Matt Hilton 
+(c) 2007-2016 Matt Hilton 
 
 U{http://astlib.sourceforge.net}
 
@@ -333,24 +333,29 @@ class ImagePlot:
                 edy=eastPix[1]-y
                 ndx=northPix[0]-x
                 ndy=northPix[1]-y
-                                
-                eArrow=patches.Arrow(x, y, edx, edy, edgecolor=p['color'], facecolor=p['color'], width=p['width'])  
-                wArrow=patches.Arrow(x, y, -edx, edy, edgecolor=p['color'], facecolor=p['color'], width=p['width'])                
-
-                self.axes.add_patch(eArrow)
-                self.axes.add_patch(wArrow)
+                
+                if p['style'] == "arrows":
+                    eArrow=patches.Arrow(x, y, edx, edy, edgecolor=p['color'], facecolor=p['color'], width=p['width'])  
+                    wArrow=patches.Arrow(x, y, -edx, edy, edgecolor=p['color'], facecolor=p['color'], width=p['width'])   
+                    self.axes.add_patch(eArrow)
+                    self.axes.add_patch(wArrow)
+                elif p['style'] == "whiskers":
+                    ewArrow=patches.FancyArrowPatch(posA = (x+edx, y), posB = (x-edx,y+edy), edgecolor=p['color'], facecolor=p['color'], linewidth = p['width'], arrowstyle = '|-|')  
+                    self.axes.add_patch(ewArrow)
                 
                 # Work out label
-                scaleLabel=None
-                if p['sizeArcSec'] < 60.0:
-                    scaleLabel="%.0f %s" % (p['sizeArcSec'], DOUBLE_PRIME)
-                elif p['sizeArcSec'] >= 60.0 and p['sizeArcSec'] <  3600.0:
-                    scaleLabel="%.0f %s" % (p['sizeArcSec']/60.0, PRIME)
+                if p['scaleBarLabel'] == None:
+                    scaleLabel=None
+                    if p['sizeArcSec'] < 60.0:
+                        scaleLabel="%.0f %s" % (p['sizeArcSec'], DOUBLE_PRIME)
+                    elif p['sizeArcSec'] >= 60.0 and p['sizeArcSec'] <  3600.0:
+                        scaleLabel="%.0f %s" % (p['sizeArcSec']/60.0, PRIME)
+                    else:
+                        scaleLabel="%.0f %s" % (p['sizeArcSec']/3600.0, DEG)
                 else:
-                    scaleLabel="%.0f %s" % (p['sizeArcSec']/3600.0, DEG)
-                    
+                    scaleLabel=p['scaleBarLabel']
                 pylab.text(x, y+0.025*self.data.shape[1], scaleLabel, horizontalalignment='center', 
-                                verticalalignment='center', fontsize=p['objLabelSize'], color=p['color'])
+                           verticalalignment='center', fontsize=p['objLabelSize'], color=p['color'])
                                 
         if self.axesLabels != None:
             pylab.xticks(self.ticsRA[0], self.ticsRA[1], weight='normal', family=self.axesFontFamily, \
@@ -659,7 +664,7 @@ class ImagePlot:
 
 
     def addScaleBar(self, location, sizeArcSec, color = "white", fontSize = 12, \
-                        width = 20.0):
+                        width = 20.0, label = None, style = "whiskers"):
         """Adds a scale bar to the ImagePlot at the given location ('N', 'NE', 'E', 'SE', 'S', 
         'SW', 'W', or 'NW'). Note these aren't directions on the WCS coordinate grid, they are 
         relative positions on the plot - so N is top centre, NE is top right, SW is bottom right etc.. 
@@ -677,6 +682,10 @@ class ImagePlot:
         @param fontSize: size of font used to label N and E, in points
         @type width: float
         @param width: width of arrow used to mark scale
+        @type label: string
+        @param label: overrides the displayed label if not None (if None, label is the angular size)
+        @type style: string
+        @param style: either "whiskers" or "arrows"
         
         """
         
@@ -746,13 +755,16 @@ class ImagePlot:
                 p['width']=width
                 p['color']=color
                 p['objLabelSize']=fontSize
+                p['scaleBarLabel']=label
+                p['style']=style
                 alreadyGot=True
         
         if alreadyGot == False:
             self.plotObjects.append({'x': [x], 'y': [y], 'RA': [RADeg], 'dec': [decDeg],
                                 'tag': "scaleBar", 'objLabels': [None], 'symbol': "scaleBar", 
                                 'width': width, 'color': color,
-                                'objLabelSize': fontSize, 'sizeArcSec': sizeArcSec})
+                                'objLabelSize': fontSize, 'sizeArcSec': sizeArcSec,
+                                'scaleBarLabel': label, 'style': style})
         self.draw()
                                 
 
